package ru.ulstu.model;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;
import java.util.Date;

@Entity
@Table(name = "is_user_sessions")
public class UserSession extends BaseEntity {
    @NotNull
    @Column(name = "session_id", nullable = false, unique = true)
    private String sessionId;

    @NotNull
    @Column(name = "ip_address", nullable = false)
    private String ipAddress;

    @NotNull
    @Column(nullable = false)
    private String host;

    @NotNull
    @Column(name = "login_time", nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date loginTime;

    @Column(name = "logout_time")
    @Temporal(TemporalType.TIMESTAMP)
    private Date logoutTime;

    @ManyToOne(optional = false)
    @JoinColumn(name = "user_id")
    private User user;

    public UserSession() {
    }

    public UserSession(String sessionId, String ipAddress, String host, User user) {
        this.sessionId = sessionId;
        this.ipAddress = ipAddress;
        this.host = host;
        this.loginTime = new Date();
        this.user = user;
    }

    public String getSessionId() {
        return sessionId;
    }

    public String getIpAddress() {
        return ipAddress;
    }

    public String getHost() {
        return host;
    }

    public Date getLoginTime() {
        return loginTime;
    }

    public Date getLogoutTime() {
        return logoutTime;
    }

    public User getUser() {
        return user;
    }

    public void setSessionId(String sessionId) {
        this.sessionId = sessionId;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public void setHost(String host) {
        this.host = host;
    }

    public void setLoginTime(Date loginTime) {
        this.loginTime = loginTime;
    }

    public void setLogoutTime(Date logoutTime) {
        this.logoutTime = logoutTime;
    }

    public void setUser(User user) {
        this.user = user;
    }

    public void close() {
        this.logoutTime = new Date();
    }
}
